==> eboard-0.3.3.tar.gz: eboard-0.3.3/protocol.cc <==
/* $Id: protocol.cc,v 1.19 2001/09/04 19:27:19 bergo Exp $ */

/*

    eboard - chess client
    http://eboard.sourceforge.net
    Copyright (C) 2000-2001 Felipe Paulo Guazzi Bergo
    bergo@seul.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/



#include "protocol.h"
#include "global.h"

void ProtocolParser::finalize() {

}

int  ProtocolParser::hasAuthenticationPrompts() {
  return 0;
}

void ProtocolParser::discardGame(int gameid) {

}

void ProtocolParser::queryGameList(GameListConsumer *glc) {
  glc->endOfList();
}

void ProtocolParser::queryAdList(GameListConsumer *glc) {
  glc->endOfList();
}

void ProtocolParser::observe(int gameid) {

}

void ProtocolParser::answerAd(int adid) {

}

void ProtocolParser::exaForward(int n) {

}

void ProtocolParser::exaBackward(int n) {

}

void ProtocolParser::sendDrop(piece p,int x,int y) {
  // not all protocols need to support {bug,crazy}house
}

void ProtocolParser::refreshSeeks() {
  // not all protocols need to manage a seek table
}

void NullProtocolParser::receiveString(char *netstring) {
  global.output->append(netstring,0xffffff);
}

void NullProtocolParser::sendMove(int x1,int y1,int x2,int y2,int prom) {

}

void NullProtocolParser::resign() {

}

void NullProtocolParser::draw() {

}

void NullProtocolParser::adjourn() {

}

void NullProtocolParser::abort() {

}

==> eboard-0.3.5.tar.gz: eboard-0.3.5/protocol.cc <==
/* $Id: protocol.cc,v 1.20 2001/10/13 00:22:10 bergo Exp $ */

/*

    eboard - chess client
    http://eboard.sourceforge.net
    Copyright (C) 2000-2001 Felipe Paulo Guazzi Bergo
    bergo@seul.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/



#include "protocol.h"
#include "global.h"

void ProtocolParser::finalize() {

}

int  ProtocolParser::hasAuthenticationPrompts() {
  return 0;
}

void ProtocolParser::discardGame(int gameid) {

}

void ProtocolParser::queryGameList(GameListConsumer *glc) {
  glc->endOfList();
}

void ProtocolParser::queryAdList(GameListConsumer *glc) {
  glc->endOfList();
}

void ProtocolParser::observe(int gameid) {

}

void ProtocolParser::answerAd(int adid) {

}

void ProtocolParser::exaForward(int n) {

}

void ProtocolParser::exaBackward(int n) {

}

void ProtocolParser::sendDrop(piece p,int x,int y) {
  // not all protocols need to support {bug,crazy}house
}

void ProtocolParser::refreshSeeks() {
  // not all protocols need to manage a seek table
}

vector<string *> * ProtocolParser::getPlayerActions() {
  return NULL;
}

vector<string *> * ProtocolParser::getGameActions() {
  return NULL;
}

void ProtocolParser::callPlayerAction(char *player, string *action) {

}

void ProtocolParser::callGameAction(int gameid, string *action) {

}

void NullProtocolParser::receiveString(char *netstring) {
  global.output->append(netstring,0xffffff);
}

void NullProtocolParser::sendMove(int x1,int y1,int x2,int y2,int prom) {

}

void NullProtocolParser::resign() {

}

void NullProtocolParser::draw() {

}

void NullProtocolParser::adjourn() {

}

void NullProtocolParser::abort() {

}
